Function invert_case
Source pub fn invert_case(text: &str) -> String
Inverts the case of each character in a string.
Arguments
text - A string slice that holds the text to invert.
Returns
- A
String containing the inverted case text.
Examples
let text = "Hello World";
let result = loki_text::transform::invert_case(text);
assert_eq!(result, "hELLO wORLD");